@@ -252,7 +252,7 @@ def main():
     branch_tag = python_version
     tag_message = "%s version %s" % (mode.capitalize(), python_version)
     try:
-        repo.git.tag(branch_tag, branch, sign_tag_opt, "-m=%s" % tag_message)
+        repo.git.tag(branch_tag, branch, sign_tag_opt, "-m %s" % tag_message)
     except GitCommandError:
         # Tag may already exist, if only the debian branch has changed
         pass
@@ -295,7 +295,7 @@ def main():
     debian_branch_tag = "debian/" + utils.version_to_tag(debian_version)
     tag_message = "%s version %s" % (mode.capitalize(), debian_version)
     if mode == "release":
-        repo.git.tag(debian_branch_tag, sign_tag_opt, "-m=%s" % tag_message)
+        repo.git.tag(debian_branch_tag, sign_tag_opt, "-m %s" % tag_message)
 
     # Add version.py files to repo
     call("grep \"__version_vcs\" -r . -l -I | xargs git add -f")
